### Name: MimModels
### Title: Create undirected and block recursive MIM models
### Aliases: mim chainmim DF DF.mim deviance.mim cliques likelihood
### Keywords: models

### ** Examples

# Create som models (no data needed!)
gmd.rats.nodata  <-  gmData(c("Sex","Drug","W1","W2"),
    factor=c(2,3,FALSE,FALSE),
    vallabels=list("Sex"=c("M","F"), "Drug"=c("D1","D2","D3")))

m12   <- mim("Sex:Drug/Sex:Drug:W1+Sex:Drug:W2/W1:W2", data=gmd.rats.nodata)
m22   <- mim("ab/abc+abd/cd", data=gmd.rats.nodata, letter=TRUE)

summary(m12)
summary(m22)

m.main <- mim(".",  data=gmd.rats.nodata)
m.sat  <- mim("..",  data=gmd.rats.nodata)
m.hsat <- mim("..h", data=gmd.rats.nodata)

summary(m.main); 
summary(m.sat); 
summary(m.hsat)

# Next we need some data to work with
data(rats)
gmd.rats <- as.gmData(rats)
vallabels(gmd.rats)
observations(gmd.rats)

m1   <- mim("Sex:Drug/Sex:Drug:W1+Sex:Drug:W2/W1:W2", data=gmd.rats)
m2   <- mim("ab/abc+abd/cd", data=gmd.rats, letter=TRUE)

m.main <- mim(".",   data=gmd.rats, marginal=c("Sex", "Drug", "W1"))
m.sat  <- mim("..",  data=gmd.rats, marginal=c("Sex", "Drug", "W1"))
m.hsat <- mim("..h", data=gmd.rats, marginal=c("Sex", "Drug", "W1"))

m1f  <- fit(m1)
m2f  <- fit(m2)

summary(m1f)
summary(m2f)

m.main <- fit(mim(".",  data=gmd.rats))
m.sat  <- fit(mim("..",  data=gmd.rats))
m.hsat <- fit(mim("..h", data=gmd.rats))

summary(m.main); 
summary(m.sat); 
summary(m.hsat)

# To generate an nth order hierarchical log-linear model for discrete
# data you can do

data(HairEyeColor)
mim(nthOrderModel(names(dimnames(HairEyeColor)),order=2),data=as.gmData(HairEyeColor))




