\name{LINPREDICT}
\alias{linpredict}
\alias{linpredict.mim}
\alias{displayMIM}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{mimR version of MIM command 'display'}
\description{
  This function returns the conditional mean and covariance of y given x
  if y is coninuous and the linear predictor of y given x if x is
  discrete.
}
\usage{
linpredict(mim,y, x=NULL,letter=FALSE, submitData=TRUE, submitModel=TRUE)
displayMIM(y, x=NULL)


}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{mim}{A mim model object}'
  \item{submitData}{If TRUE data  are submitted to MIM, otherwise
    not. If data is already loaded in MIM, setting submitData=FALSE
    saves some time}
  \item{submitModel}{If TRUE the model is submitted to MIM, otherwise
    not. If the model is already the model in, setting submitModel=FALSE
    saves some time}
  \item{y}{ Vector of response variables}
  \item{x}{ Vector of explanatory variables}
  \item{letter}{If TRUE then x and y contains the variables as letters
    (instead of as proper names)}
}
\details{
  The implementation of linpredict is slightly fragile and certainly not
  elegant. Please use it with caution.
  The displayMIM function is not intended for the user
}
\value{
  Returns a linpredictMIM object which is a list of lists containing the
  quantities returned.
}

\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

\section{WARNING }{
If a and b are discrete and x and y are coninuous, then the MIM command
display by,ax will return the linear predictor of b given a,x and the
conditional mean and variance of y given a,x.

In mimR, on the other hand, the response types can not be mixed, so you
should do it in two steps.
} 

\seealso{\code{\link{fitted}}}

\examples{
data(rats)
gmd.rats <- as.gmData(rats)
m1   <- mim("Sex:Drug/Sex:Drug:W1+Sex:Drug:W2/W1:W2", data=gmd.rats)
mf1  <- fit(m1)
d1  <- linpredict(mf1, y="W2",    x="W1:Sex") 
d2  <- linpredict(mf1, y="Sex",   x="W1:W2")
d3  <- linpredict(mf1, y="W1:W2", x="Sex")
d4  <- linpredict(mf1, y="W1:W2")
d5  <- linpredict(mf1, y="Sex")
d1; d2; d3; d4; d5
}
\keyword{models}
%\keyword{ ~kwd1 }% at least one, from doc/KEYWORDS
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line












\eof
\name{MIMbase}
\alias{mim.cmd}
\alias{mcm}

%- Also NEED an `\alias' for EACH other topic documented here.
\title{Submit commands to MIM and get the result back in R}
\description{
  mim.cmd is the core function for communicating with MIM from within R.
  MIM commands are given as text strings and the results from submitting
  these commands in MIM are returned (as a vector of strings). Several
  functions exist for processing these results in sensible ways. See below.

  Invoking mcm() gives a direct interface to MIM such that MIM commands
  can be entered directly. The output printed by MIM is printed the same
  way in the R console.

}
\usage{
mim.cmd(cmd, look.nice = TRUE, return.look.nice=FALSE, version='R')
mcm()
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{cmd}{A (vector of) strings of MIM commands}
  \item{look.nice}{When TRUE the result of the last MIM command is
    printed on the screen and returned as a list of strings, one string
    per line of output. When FALSE the result is returned as a vector
    of strings (thereby enabeling processing of the results in R).}
  \item{return.look.nice}{When TRUE the result of the last MIM command is
    returned as a list of strings, one string
    per line of output.}
  \item{version}{If set to 'S' then the function also should work with Splus}
}
\details{
  To exit the mcm() function, type quit, end, exit, q or e at the
  prompt. Note that this will not terminate the MIM program.
}

\value{
  mim.cmd returns a vector or a string, whereas mcm returns NULL
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{ }

\examples{
mim.cmd("fact a2 b2 c2; statread abc")
mim.cmd("25 2 17 8 14 9 6 8 !")
mim.cmd("mod ab,ac,bc; fit")
##mcm()
}

\keyword{models}
%\keyword{ ~kwd1 }% at least one, from doc/KEYWORDS
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line

\eof
\name{FIT}
\alias{fit}
\alias{emfit}

%- Also NEED an `\alias' for EACH other topic documented here.
\title{Function to fit model in MIM}
\description{
  Fits model in MIM either directly or using an EM--algorithm in the
  case of incomplete data
}
\usage{
fit(mim, submitData=TRUE)
emfit(mim, arg = "R", submitData=TRUE, emconv=0.0001, emmax=1000, plot = FALSE,info=FALSE) %
}
\arguments{
  \item{mim}{ A mim model object}
  \item{submitData}{If TRUE  data are submitted to MIM, otherwise
    not. If data is already loaded in MIM, setting submitData=FALSE
    saves some time}
  \item{arg}{ can be one of the letters "R", "S" or "F"}
  %\item{plot}{ if TRUE, a plot of the convergence history of the EM
  %  algorithm is made.}
  \item{emconv}{Convergence criterion for EM algorithm}
  \item{emmax} {Maximum number of iterations for EM algorithm}
  \item{plot}{If TRUE, the convergence history of the EM algorithm is
    plotted}
  \item{info}{If TRUE, information about EM fit is printed}
}
\details{
  The S option enables the user to supply start values for the missing
  data: as with the R option these are used to calculate the sufficient
  statistics, and thence the initial parameter estimates.
  First start values are entered, and then these are overwritten 
  with an asterix (missing value).
  For an example of how to do this, see the examples below.

  The start values can be entered using EditData in MIM: first enter the desired
  value, and then overwrite this with an asterix (missing value). Check
  using Print E in MIM that the values have been correctly entered.
}
\value{
  Returns a fitted mim object
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

%~Make other sections like WARNING with \section{WARNING }{....} ~

%\seealso{\code{\link{mim.emfit}} }

\examples{
data(mathmark)
math     <- mathmark
math$L   <- factor(NA, levels=1:2)
gmd.math <- as.gmData(math)
latent(gmd.math) <- "L"
m1  <- mim("..", data=gmd.math)
m2  <- editmim(m1, deleteEdge=paste(names(math)[1:5],":",collapse='')) 
m2f <- emfit(m2)
imputeMissing()
d.imp <- retrieveData()
}
\keyword{models}% at least one, from doc/KEYWORDS
%\keyword{utilities}
%\keyword{ ~kwd1 }% at least one, from doc/KEYWORDS
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line





\eof
\name{MimModels}

\alias{mim}
\alias{chainmim}
\alias{DF}
\alias{DF.mim}
\alias{deviance.mim}
\alias{cliques}
\alias{likelihood}

%\alias{mim.br.model}
%\alias{submit}
%\alias{submit.mimModel}
%\alias{submit.mimBRModel}
%\alias{print.mimModel}
%\alias{print.mimBRModel}
%\alias{formula.mimModel}

%\alias{deviance.mimModel}
%\alias{dof.mimModel}


%\alias{display}
%\alias{display.mimModel}
%\alias{mimData.mimModel}


%- Also NEED an `\alias' for EACH other topic documented here.
\title{Create undirected and block recursive MIM models }
\description{
  ...........
}

\usage{
mim(mimFormula, data, letter=FALSE, marginal=data$name)
%chainmim(mimFormula.list, data)
%mim.br.model(mim.formula, data, mim.names = TRUE, submit = TRUE, fit=TRUE)

}

\arguments{
  \item{mimFormula}{A model formula following the MIM syntax. Long
    variable names are allowed however. See 'details'. The formula can
    be given either with a tilde or as a string}
%  \item{mimFormula.list}{A list of mim formulae}
  \item{data}{A gmData object}
  \item{letter}{If TRUE, the variables used in mim.formula are single
  letters.}
  \item{marginal}{Can be used for specifying only a subset of the
    variables in connection with a main effects, a saturated and a
    homogeneous saturated model}
%\item{submit}{If TRUE, the model is submitted to MIM}
%\item{fit}{If TRUE the model is fitted in MIM}
%\item{x}{A mimModel or mimBRModel object}
} 
\details{
  A mim.formula can be
  "Sex+Drug/Sex:W1+Drug:W1+Sex:W2+Drug:W2/Sex:W1:W2+Drug:W1:W2" or (if
  letter is TRUE) the shorter form  "ab/abx,aby/abxy"  or
  "ab/abx+aby/abxy".
  A mimFormula can also be "." (the main effects (the
  independence) model), ".." (the saturated model) or "..h"
  (the homogeneous saturated model).
  See 'examples'.
}
\value{
  A mimModel or mimBRModel object
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{\code{\link{as.gmData}}}

\examples{
# Create som models (no data needed!)
gmd.rats.nodata  <-  gmData(c("Sex","Drug","W1","W2"),
    factor=c(2,3,FALSE,FALSE),
    vallabels=list("Sex"=c("M","F"), "Drug"=c("D1","D2","D3")))


m12   <- mim("Sex:Drug/Sex:Drug:W1+Sex:Drug:W2/W1:W2", data=gmd.rats.nodata)
m22   <- mim("ab/abc+abd/cd", data=gmd.rats.nodata, letter=TRUE)

summary(m12)
summary(m22)

m.main <- mim(".",  data=gmd.rats.nodata)
m.sat  <- mim("..",  data=gmd.rats.nodata)
m.hsat <- mim("..h", data=gmd.rats.nodata)

summary(m.main); 
summary(m.sat); 
summary(m.hsat)

# Next we need some data to work with
data(rats)
gmd.rats <- as.gmData(rats)
vallabels(gmd.rats)
observations(gmd.rats)

m1   <- mim("Sex:Drug/Sex:Drug:W1+Sex:Drug:W2/W1:W2", data=gmd.rats)
m2   <- mim("ab/abc+abd/cd", data=gmd.rats, letter=TRUE)

m.main <- mim(".",   data=gmd.rats, marginal=c("Sex", "Drug", "W1"))
m.sat  <- mim("..",  data=gmd.rats, marginal=c("Sex", "Drug", "W1"))
m.hsat <- mim("..h", data=gmd.rats, marginal=c("Sex", "Drug", "W1"))

m1f  <- fit(m1)
m2f  <- fit(m2)

summary(m1f)
summary(m2f)

m.main <- fit(mim(".",  data=gmd.rats))
m.sat  <- fit(mim("..",  data=gmd.rats))
m.hsat <- fit(mim("..h", data=gmd.rats))

summary(m.main); 
summary(m.sat); 
summary(m.hsat)

# To generate an nth order hierarchical log-linear model for discrete
# data you can do

data(HairEyeColor)
mim(nthOrderModel(names(dimnames(HairEyeColor)),order=2),data=as.gmData(HairEyeColor))


}
\keyword{models}% at least one, from doc/KEYWORDS

\eof
\name{stepwise}

\alias{stepwise}
\alias{stepwise.mim}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Stepwise model selection in MIM}
\description{
  Functions to do stepwise model selection in MIM to achieve a new model
  object.  }

\usage{
stepwise(x, arg = NULL)
}
%- maybe also `usage' for

\arguments{
  \item{x}{A mimModel object}
  \item{arg}{Stepwise options to MIM}
}
\value{
  a mimModel object
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

%\seealso{ ~~objects to See Also as \code{\link{~~fun~~}}, ~~~ }

\examples{
data(carcass)
gmd.carc <- as.gmData(carcass)

m.main <- fit(mim(~.,  data=gmd.carc))
m.sat  <- fit(mim(~..,  data=gmd.carc))

m.main <- mim(~.,  data=gmd.carc)
m.sat  <- mim(~..,  data=gmd.carc)

m.m <- stepwise(m.main, "f")    # forward
m.s <- stepwise(m.sat, "s")     # backward, exact tests
}
\keyword{models}% at least one, from doc/KEYWORDS


\eof
\name{mimR-ReadingData}

\alias{gmData}
\alias{as.gmData}
\alias{as.gmData.data.frame}
\alias{as.gmData.table}
\alias{as.gmData.suffStats}

\alias{description}
\alias{description.gmData}
\alias{description<-}
\alias{description<-.gmData}

\alias{latent}
\alias{latent.gmData}
\alias{latent<-}
\alias{latent<-.gmData}

\alias{vallabels}
\alias{vallabels.gmData}
\alias{vallabels<-}
\alias{vallabels<-.gmData}

\alias{observations}
\alias{obs}
\alias{observations.gmData}
\alias{observations<-}
\alias{observations<-.gmData}

%- Also NEED an `\alias' for EACH other topic documented here.
\title{Creation of gmData objects}
\description{
  Different methods for creation of gmData objects. Depending on taste
  gmData can be taken as meaning 'graphical model data' or 'graphical
  meta data'
}
\usage{
gmData(name, letter = c(letters, LETTERS), factor = rep(FALSE,
length(name)), vallabels=NULL, data=NULL)
as.gmData (data, letter=c(letters,LETTERS))
description(x)
"description<-"(tmp, value)
latent(x)
"latent<-"(tmp, value)
vallabels(x)
"vallabels<-"(tmp, value)
observations(x)
"observations<-"(tmp, value)

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{name}{ ~~Describe \code{name} here~~ }
  \item{factor}{ ~~Describe \code{factor} here~~ }
  \item{data}{a dataframe}
  \item{letter}{A specification of letters which can subsequently
    be used as short hand for the variable names}
  \item{x}{A gmData object}
  \item{tmp}{A gmData object}
  \item{value}{The value to entered into the object}
  %\item{text}{A text string}
  \item{vallabels}{A list containing labels of the levels of the
    discrete variables (not currently used)}
  %\item{variables}{A set of variables}
  %\item{obs}{Data to be used in the object. Can be a data frame, a
  %  table or a set of sufficient statistics (as used by MIM)}
  %\item{labels}{A list in which each item consists of a vector with
  %  labels of the factors in the gmData object. See examples below.}
}
\details{
 as.mimData is just a wrapper for as.gmData (kept in the package for
 historical reasons). as.mimData only works for data frames.
}
\value{
  A dataframe containing the link between the names in the dataframe and
  the names (and labels) and the coding of factors in MIM
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

\section{WARNING}{
If only a subset of a dataframe is used, then it may be necessary to
recode the levels of factors in the dataframe. Otherwise one can end up with
slices of the table in MIM with no observations in it. The easiest way
to recode the levels is to use the function 'factor()', see examples below.
} 

\seealso{\code{\link{mim.cmd}}}

\examples{
# A meta data object (without data)
gmd.rats.nodata  <-  gmData(c("Sex","Drug","W1","W2"),
    factor=c(2,3,FALSE,FALSE),
    vallabels=list("Sex"=c("M","F"), "Drug"=c("D1","D2","D3")))

# Note care should be taken to be consistent when specifying vallabels manually:

#This works
nt1  <-  gmData(c("Sex","Drug","W1","W2"),factor=c(2,3,FALSE,FALSE))
vallabels(nt1)

#This works
nt12  <-  gmData(c("Sex","Drug","W1","W2"),factor=c(2,3,FALSE,FALSE), vallabels=list("Sex"=c(1,2), "Drug"=c(1,2,3)))
vallabels(nt1)

\dontrun{
#This will not work
nt1  <-  gmData(c("Sex","Drug","W1","W2"),factor=c(2,3,FALSE,FALSE), vallabels=list("Sex"=c(1,2,3), "Drug"=c(1,2,3)))
vallabels(nt1)

#This will not work
nt1  <-  gmData(c("Sex","Drug","W1","W2"),factor=c(2,3,FALSE,FALSE), vallabels=list("Sex"=c(1,2,3)))
vallabels(nt1)
}


data(rats)

#NOTE: This works, but it should not because names in 'data' is not checked for consistency with what is specified
nt1  <-  gmData(c("Sex","Drug","W1","W2"),factor=c(2,3,FALSE,FALSE), vallabels=list("Sex"=c(1,2), "Drug"=c(1,2,3)), data=rats)
vallabels(nt1)

# Sending a data frame to MIM
gm.rats <- as.gmData(rats)
toMIM(gm.rats)
}
\keyword{models}% at least one, from doc/KEYWORDS
%\keyword{utilities}% at least one, from doc/KEYWORDS
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line


\eof
\name{cadcomplete}
\alias{cadcomplete}
\alias{cadincomplete}
\docType{data}
\title{Coronary artery disease data}
\description{
Coronary artery disease data
}
\usage{data(cadcomplete)}
\format{
  A data frame with 236 observations on the following 14 variables.
  \describe{
    \item{Sex}{a numeric vector}
    \item{AngPec}{a numeric vector}
    \item{AMI}{a numeric vector}
    \item{QWave}{a numeric vector}
    \item{QWavecode}{a numeric vector}
    \item{STcode}{a numeric vector}
    \item{STchange}{a numeric vector}
    \item{SuffHeartF}{a numeric vector}
    \item{Hypertrophi}{a numeric vector}
    \item{Hyperchol}{a numeric vector}
    \item{Smoker}{a numeric vector}
    \item{Inherit}{a numeric vector}
    \item{Heartfail}{a numeric vector}
    \item{CAD}{a numeric vector}
  }
}
\details{

}
\source{
  ~~ reference to a publication or URL from which the data were obtained ~~
}
\references{
  ~~ possibly secondary sources and usages ~~
}
\examples{
data(cadcomplete)
## maybe str(cadcomplete) ; plot(cadcomplete) ...
}
\keyword{datasets}

\eof
\name{carcass}
\alias{carcass}
\non_function{}
\title{lean meat contents of pig carcasses}
\usage{data(carcass)}
\description{
  Measurement of lean meat percentage and thickness of meat and fat
  layers at different locations of 344 pig carcasses.
}
\format{
  A data frame with 7 variables and 344 observations. LMP is the lean
  meat percentage determined by dissection. F11, F12 and F13 are
  measurements of fat depth at three different locations on the carcass
  and M11, M12 and M13 are measurements of meat depth at the same
  locations.
}
\source{
 Busk, Hans XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
}
\references{
~~ possibly secondary sources and usages ~~
}
\keyword{datasets}

\eof
\name{create.table}
\alias{create.table}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Create dataframe for a contingency table}
\description{
  Creates a dataframe with 6 rows for a 2x3 table.
}
\usage{
create.table(levels, names = NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{levels}{A vector of levels}
  \item{names}{A vector with names}
}
\value{
A dataframe
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}
% ~Make other sections like WARNING with \section{WARNING }{....} ~

%\seealso{ ~~objects to SEE ALSO as \code{\link{~~fun~~}}, ~~~ }

\examples{
create.table(c(2,3,2),c("a","b","c"))
}
\keyword{utilities}% at least one, from doc/KEYWORDS


\eof
\name{dietox}
\alias{dietox}
\non_function{}
\title{Growth curves of pigs in a 3x3 factorial experiment}
\usage{data(dietox)}
\description{
The \code{dietox} data frame has 861 rows and 7 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Weight}{a numeric vector}
    \item{Feed}{a numeric vector}
    \item{Time}{a numeric vector}
    \item{Pig}{a numeric vector}
    \item{Evit}{a numeric vector}
    \item{Cu}{a numeric vector}
    \item{Litter}{a numeric vector}
  }
}
%\details{
% ~~ If necessary, more details than the description above ~~
%}
\source{
  Lauridsen, C., Hjsgaard, S.,Srensen, M.T. C. (1999) Influence of
Dietary Rapeseed Oli, Vitamin E, and Copper on Performance and
  Antioxidant and Oxidative Status of Pigs. J. Anim. Sci.77:906-916
}
%\references{
%~~ possibly secondary sources and usages ~~
%}
\examples{
data(dietox)
## maybe str(dietox) ; plot(dietox) ...
}
\keyword{datasets}

\eof
\name{editMIM}
\alias{editmim}
\alias{testdelete}
\alias{retrieveMIMvalues}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Editing a mim model object}
\description{
  Editing a mim model object by adding/deleting edges.
}
\usage{
editmim(x, deleteEdge=NULL, addEdge=NULL, haddEdge=NULL,
                    deleteTerm=NULL, addTerm=NULL, letter=FALSE)
testdelete(edge, mim, options=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{A mim model object }
  \item{deleteEdge}{Edges to be deleted}
  \item{addEdge}{Edges to be added}
  \item{haddEdge}{Edges to be added (homogeneously)}
  \item{deleteTerm}{Terms to be deleted}
  \item{addTerm}{Terms to be added}
  \item{letter}{If TRUE, the variables are specified using single
    letters.}
  \item{edge}{Edge to be tested}
  \item{mim}{A mim object}
  \item{options}{Additional arguments to MIM specifying the tests}
}
\details{
  retrieve is used for retrieving a model (as a mim object) manually
  from MIM after e.g. altering a model in the MIM program directly
}
\value{
  A new mim model object
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like Warning with \section{Warning }{....} ~ 
%\seealso{ ~~objects to See Also as \code{\link{~~fun~~}}, ~~~ }
\examples{
data(rats)
gmd.rats <- as.gmData(rats)
m.main <- mim(".",  data=gmd.rats)
m2 <- editmim(m.main, addEdge=c("Sex:Drug", "Sex:W2"))
m3 <- editmim(m.main, addEdge=c("Sex:Drug", "Sex:W2"),haddEdge="Drug:W1:W2")

summary(m2)
summary(m3)
}
\keyword{models}% at least one, from doc/KEYWORDS

\eof
\name{fitted.mim}
\alias{fitted.mim}
\alias{modelInfo}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Extract fitted values (parameter estimates) }
\description{
  Extracts fitted values (parameter estimates) from a mim model.
}
\usage{
fitted.mim(object, ...)
modelInfo(object)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{ A mim model object}
  \item{\dots}{ Other argumens}
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  A data frame
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{\code{\link{simulate}}}
\examples{
data(rats)
gmd.rats <- as.gmData(rats)
m2    <- mim("ab/abc+abd/cd", data=gmd.rats, letter=TRUE)
mf2   <- fit(m2)
parms <- fitted(mf2)
parms


m3    <- mim("a,b", data=gmd.rats, letter=TRUE)
mf3   <- fit(m3)
parms <- fitted(mf3)
parms

m4    <- mim("//cd", data=gmd.rats, letter=TRUE)
mf4   <- fit(m4)
parms <- fitted(mf4)
parms
}
\keyword{models}% at least one, from doc/KEYWORDS


\eof
\name{imputeMissing}
\alias{imputeMissing}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Impute missing values}
\description{
  Imputes missing values in a data set in MIM after a model has been
  fitted.
  }
\usage{
imputeMissing()
}
%- maybe also 'usage' for other objects documented here.
\value{
  None
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}
\seealso{\code{\link{emfit}}}
\examples{
}
\keyword{models}% at least one, from doc/KEYWORDS


\eof
\name{mathmark}
\alias{mathmark}
\non_function{}
\title{Mathematics marks for students}
\usage{data(mathmark)}
\description{
The \code{mathmark} data frame has 88 rows and 5 columns.
~~ Give a concise description here ~~
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{mechanics}{a numeric vector}
    \item{vectors}{a numeric vector}
    \item{algebra}{a numeric vector}
    \item{analysis}{a numeric vector}
    \item{statistics}{a numeric vector}
  }
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}
\examples{
data(mathmark)
## maybe str(mathmark) ; plot(mathmark) ...
}
\keyword{datasets}

\eof
\name{mimR}
\alias{mimR}
\title{
The package `mimR': summary information
}
\description{
This package provides an interface to the MIM program for inference in
mixed graphical models.
}
\section{Details}{
\itemize{
  \item mimR is available on Windows platforms only.
  \item mimR requires that the MIM program is installed on the computer.
  \item MIM can be downloaded from http://www.hypergraph.dk.
  \item mimR requires that the R package RDCOMClient package is installed.
  \item The RDCOMClient package can be downloaded from http://www.omegahat.org/download/R/packages/Windows/R-2.0.0/
  \item For information about required versions of R, MIM and the
  RDCOMClient, please see the information presented when mimR is loaded.

  To start using mimR you must do
  library(mimR)
  library(RDCOMClient)
  }
The package is intended as a contribution to the gR-project 
derscribed by Lauritzen (2002).
}
\section{Authors}{
Sren Hjsgaard, Biometry Research Unit, Danish Institute of
Agricultural Sciences, DK-8830 Tjele, Denmark
}
\section{Acknowledgements}{
  Thanks to David Edwards, the creator of the MIM program.
}
\references{
Lauritzen, S. L. (2002). gRaphical Models in R.
\emph{R News}, 3(2)39.
}
\keyword{multivariate}
\keyword{models}
\keyword{graphs}

\eof
\name{mimRprint-MIM}
\alias{print.mim}
\alias{summary.mim}
\alias{properties}
\alias{properties.mim}
\alias{print.linpredictMIM}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{Print methods for objects in mimR}
\description{
  Print methods for objects in mimR

}
\usage{
print.mim(x, ...)
print.linpredictMIM(x, ...)
properties(object)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{An object of appropriate class}
  \item{object}{a mim object}
  \item{\dots}{Has no effect}
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  x
}

\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like Warning with \section{Warning }{....} ~ 
%\seealso{ ~~objects to See Also as \code{\link{~~fun~~}}, ~~~ }
\examples{
}
\keyword{print}% at least one, from doc/KEYWORDS

\eof
\name{mimRprint}
\alias{print.gmData}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{Print methods for objects in mimR}
\description{
  Print methods for objects in mimR

}
\usage{
print.gmData(x, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{An object of appropriate class}
  \item{\dots}{Has no effect}
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  x
}

\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like Warning with \section{Warning }{....} ~ 
%\seealso{ ~~objects to See Also as \code{\link{~~fun~~}}, ~~~ }
\examples{
}
\keyword{print}% at least one, from doc/KEYWORDS

\eof
\name{nthOrderModel}
\alias{nthOrderModel}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Create generating class with nth order interactions for log--linear model}
\description{
  Creates  generating class with nth order interactions for log--linear
  model
  }
\usage{
nthOrderModel(variables, order = 2)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{variables}{A vector of variables}
  \item{order}{The maximum order of interactions in the model}
}
\value{
  A string
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}
\examples{
nthOrderModel(c("ss","uu","ii"), 2)
}
\keyword{models}% at least one, from doc/KEYWORDS


\eof
\name{printMIM}
\alias{printMIM}
\title{Function for printing data, models, parameter estimates etc. in MIM}
\description{
  Submits the command 'Print <letter>' where the possible letters can be
  looked up in the MIM online help or David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002. The result is interpreted in a suitable way and
  returned to the user
}
\usage{
printMIM(arg = NULL, verbose=FALSE)
}
\arguments{
  \item{arg}{A letter or NULL. When NULL the model is returned. See
    'details' below.}
  \item{verbose}{If TRUE noting is printed}
}
\details{
  S:
 empirical counts, means and covariances
 
T:
 empirical counts, linear parameters and precisions
 
U:
 empirical counts, means and correlations
 
V:
 empirical counts, linear parameters and partial correlations
 
F:
 fitted counts, means and covariances
 
G:
 fitted counts, linear parameters and precisions
 
H:
 fitted counts, means and correlations
 
I:
 fitted counts, linear parameters and partial correlations
 
NULL (the default):
 the formula of the current model. In block mode, this is the current block-recursive model, otherwise, it is the current undirected model.
 
M:
 the formula of the current undirected model.
 
B:
 the formula of the current block-recursive model.
 
W:
 The AIC and BIC of the current model.
 
X:
 minus twice the log likelihood of the saturated (or maximum) model
 
Y:
 minus twice the log likelihood of the current model
 
Z:
 the deviance of the current model.
 
C:
 the raw data (using value labels)
 
D:
 the raw data (using levels)
 
E:
 the raw data (showing missing values)
}
\value{
  What is returned depend on the arg, i.e. on the letter 
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}
% ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{
  \code{\link{mim.cmd}}
}

\examples{
mim.cmd("fact a2 b2 c2; statread abc")
mim.cmd("25 2 17 8 14 9 6 8 !") 
mim.cmd("mod ab,ac,bc; fit")
printMIM("f")
printMIM("s")
}
\keyword{models}
%\keyword{ ~kwd1 }% at least one, from doc/KEYWORDS
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line

\eof
\name{rats}
\alias{rats}
\title{Weightloss of rats}
\description{
  An artificial dataset. 24 rats (12 female, 12 male) have been
  randomized to use one of three drugs (products for loosing
  weight). The weightloss for each rat is noted after one and two
  weeks. 
}
\usage{data(rats)}
\format{A dataframe with 4 variables. Sex: "M" (male), "F"
  (female). Drug:  "D1", "D2", "D3" (three types). W1 weightloss, week
  one. W2 weightloss, week 2.}
\references{
  Morrison, D.F. (1976). Multivariate Statistical Methods. McGraw-Hill, USA.

  Edwards, D. (1995). Introduction to Graphical Modelling,
  Springer-Verlag. New York.
}
\keyword{datasets}





\eof
\name{retrieveData}
\alias{retrieveData}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Retrieve data from MIM engine}
\description{
  This function can be used for retrieving data from the MIM engine. It
  is useful in connection with latent variable models
}
\usage{
retrieveData(arg="c")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{arg}{"c": the raw data (using value labels), "d": the raw data
(using levels) , "e": the raw data (showing missing values)}

}
\details{
}
\value{
  A data frame
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Springer Verlag, 2002}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

\seealso{See Also as \code{\link{emfit}}}
\examples{

}
\keyword{utilities}% at least one, from doc/KEYWORDS
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line

\eof
\name{returnValues}
\alias{returnValues}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Return fitted and observed values}
\description{
Returns fitted and observed values together with deviance etc. for MIM
model objects
}
\usage{
returnValues(object, type = "fitted", marginal = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{A mim model object}
  \item{type}{Can be either "fitted", "observed", "deviance" or
    "pearson" (the two latter only for discrete models)}
  \item{marginal}{A subset of the variables of the model}
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
A vector
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like Warning with \section{Warning }{....} ~ 
%\seealso{ ~~objects to See Also as \code{\link{~~fun~~}}, ~~~ }
\examples{
}
\keyword{ models }% at least one, from doc/KEYWORDS

\eof
\name{simulate}
\alias{simulate}
\alias{simulate.mim}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Draw random sample from a mixed interaction model (mim)}
\description{
  This function draws a random sample from a fittet mim model.
}
\usage{
simulate(mim, size, digits = 3)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mim}{A mim model object}
  \item{size}{The size of the sample}
  \item{digits}{The number of digits for the continuous variables}
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  A data frame
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{\code{\link{fitted}}}
\examples{
data(rats)
gmd.rats <- as.gmData(rats)
m2   <- mim("ab/abc+abd/cd", data=gmd.rats, letter=TRUE)
mf2 <- fit(m2)
#samp <- simulate(mf2, size=10)   # 'sample' is already used in R 
#samp 
}
\keyword{datagen}% at least one, from doc/KEYWORDS

\eof
\name{toMIM}
\alias{toMIM}
\alias{toMIM.data.frame}
\alias{toMIM.gmData}
\alias{toMIM.table}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Wrapper for submitting data and models to MIM}
\description{
  Function for submitting data and models to MIM. The function is
  primarily intended for internal use
}
\usage{
toMIM(data)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{ ~~Describe \code{data} here~~ }
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  NULL
}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}

% ~Make other sections like Warning with \section{Warning }{....} ~ 
%\seealso{ ~~objects to See Also as \code{\link{~~fun~~}}, ~~~ }
\examples{
}
\keyword{models}

\eof
\name{variableType}
\alias{variableType}
\alias{is.discrete}
\alias{is.continuous}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Information about variables in MIM model}
\description{
Retrieve information about variables in MIM model
}
\usage{
variableType(mim)
%is.discrete(mim)
%is.continuous(mim)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mim}{A mim model object}
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  variableType() returns either "discrete", "continuous" or "mixed".
  is.discrete() and is.continuous() return TRUE or FALSE

}
\references{ David Edwards, An Introduction to Graphical Modelling,
  Second Edition, Springer Verlag, 2000}
\author{Sren Hjsgaard, sorenh@agrsci.dk}
\note{Before using mimR, make sure that the MIM program is runnning.}


%\seealso{ ~~objects to See Also as \code{\link{~~fun~~}}, ~~~ }
\examples{
}
\keyword{models}% at least one, from doc/KEYWORDS


\eof
